pub enum TermProof {
PRule {
rule_name: Rc<str>,
subst: DenseIdMap<VariableId, TermId>,
body_pfs: Vec<Premise>,
result: TermId,
},
PProj {
pf_f_args_ok: TermProofId,
arg_idx: usize,
},
PCong(CongProof),
PFiat {
desc: Rc<str>,
term: TermId,
},
}Variants
PRule
proves a Proposition based on a rule application the subsitution gives the mapping from variables to terms the body_pfs gives proofs for each of the conditions in the query of the rule the act_pf gives a location in the action of the proposition
Fields

subst: DenseIdMap<VariableId, TermId>PProj
get a proof for the child of a term given a proof of a term
PCong(CongProof)
PFiat