SideChannel

Type Alias SideChannel 

pub type SideChannel<T> = Arc<Mutex<Option<T>>>;
A useful type definition for external functions that need to pass data to outside code, such as Panic.

Aliased Type

pub struct SideChannel<T> { /* private fields */ }