pub enum EqProof {
PRule {
rule_name: Rc<str>,
subst: DenseIdMap<VariableId, TermId>,
body_pfs: Vec<Premise>,
result_lhs: TermId,
result_rhs: TermId,
},
PRefl {
t_ok_pf: TermProofId,
t: TermId,
},
PSym {
eq_pf: EqProofId,
},
PTrans {
pfxy: EqProofId,
pfyz: EqProofId,
},
PCong(CongProof),
}Variants
PRule
proves a Proposition based on a rule application the subsitution gives the mapping from variables to terms the body_pfs gives proofs for each of the conditions in the query of the rule the act_pf gives a location in the action of the proposition
Fields

subst: DenseIdMap<VariableId, TermId>PRefl
A term is equal to itself- proves the proposition t = t
PSym
The symmetric equality of eq_pf
PTrans
PCong(CongProof)
Proves f(x1, y1, …) = f(x2, y2, …) where f is fun_sym A proof via congruence- one proof for each child of the term pf_f_args_ok is a proof that the term with the lhs children is valid